package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````E18``#0```"0`0$```0`!30`(``)
M`"@`&P`:``$``'"H>P``J'L``*A[```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````"T>P``M'L```4```````$`
M`0```+S]``"\_0$`O/T!`(0"``"8$@``!@```````0`"````Q/T``,3]`0#$
M_0$`"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO/T`
M`+S]`0"\_0$`1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`K5,,O/P9P)J+_U97).IXAA_,`+X$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PX@!)!B@``"$P```!-````4```
M`%0```!5````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[;49-1\=E0\E"'_Y`[9
M<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RQ8[Y=YNN.2?/NA;&!K"4/69Z_,9D)%
MU>R)!W#3,V+;[16,)<P-.I<+?ZF<F^"G`@IJ&IY0O]I7&Z/@^TD`````````
M`````````````````,P1`````````P`+``````````(```````,`%@#G`@``
M```````````2````\P``````````````$@```'8"`````````````!(```"@
M`@`````````````2````@P``````````````$@```-$``````````````!$`
M``!L`0`````````````2````"0$`````````````$@````$`````````````
M`"````"I`0`````````````2````.@$`````````````$@```"H!````````
M`````!(````=`@`````````````2````'`$`````````````$@````@"````
M`````````!(````0```````````````@````B@$`````````````$@```"P"
M`````````````!(```#X```````````````2````I`$`````````````$@``
M`.`"`````````````!(````L```````````````@````F0(`````````````
M$@```$8``````````````!(```!<`0`````````````2````8P``````````
M````$@```,```````````````!(```!T```````````````2````5@(`````
M````````$@````$"`````````````!(```"1`@`````````````2````R0,`
M````````````$@```*0``````````````!(```#O`@`````````````1````
M^@$`````````````$@````D#`````````````!$```!#`@`````````````2
M````4`(`````````````$@```$X!`````````````!(````Z`@``````````
M```2````W```````````````$@```%T"`````````````!(```#]````````
M```````2````J`(`````````````$@```(,!`````````````!(```#/`@``
M```````````2````Y0$`````````````$@```!8"`````````````!(```!*
M`@`````````````2````F`(`````````````$@```+\!`````````````!(`
M``"W`0`````````````2````]P(`````````````$@```.X"````````````
M`"$```"/```````````````2````L`$`````````````$@```'<!````````
M`````!(```#&`@`````````````2````[0(`````````````$0```(H"````
M`````````!$```"S```````````````1````;`(`````````````$@```'P"
M`````````````!(````D`@`````````````2````0P$`````````````$@``
M`&0"`````````````!(```!4```````````````2````TP$`````````````
M$@```#,"`````````````!(```#S`0`````````````2````P0(`````````
M````$@```+`"`````````````!(```"5`0`````````````B````)`0``%00
M`@``````$``7`-(#```=+```Z````!(`#0!)!```A20``-`%```2``T`X`$`
M`-D4``"\`0``$@`-`$D#```1'0``!````!(`#0!G`P``52H``,@!```2``T`
M^@,``$```@``````$``7`&\$```5'0``I`$``!(`#0`O!```0``"```````0
M`!<`6@,``+D>```6````$@`-`'T#```=(P``>````!(`#0#>`P``H#H```0`
M```1``\`"`0``/DX``#4````$@`-`!,$```Q'```.````!(`#0`;!```5!`"
M```````0`!<`1`0``%00`@``````$``7`%T$``"E(P``X````!(`#0#M`P``
M```"```````0`!8`H0,``-$>``"P````$@`-`%8$``!```(``````!``%@!\
M!```/``"``0````1`!8`\P,``)46````````$@`-`#L$``"!.```>````!(`
M#0#O`P`````"```````@`!8`MP,``)4C```0````$@`-`(L#``!I'```J```
M`!(`#0"M`P``S3D``+P````2``T`(P0``%00`@``````$``7`(8$``"!'P``
MG`,``!(`#0``7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R
M;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!?7V-X85]F:6YA;&EZ90!R96%D`'-T<F-H<@!G971P:60`;65M
M;6]V90!P=&AR96%D7V=E='-P96-I9FEC`%]?;&EB8U]S=&%R=%]M86EN`%]?
M9G!R:6YT9E]C:&L`<W1R8VUP`&]P96XV-`!U;FQI;FL`7U]S=')N8W!Y7V-H
M:P!S=')T;VL`;65M<V5T`'-T<FYC;7``9V5T=6ED`&UE;6-H<@!C;&]S961I
M<@!S=')S='(`<FUD:7(`8VQO<V4`<W1R;&5N`'-T<F1U<`!R96%L;&]C`')E
M861D:7(V-`!A8F]R=`!?7W-P<FEN=&9?8VAK`'-T9&5R<@!M96UC<'D`;'-T
M870V-`!O<&5N9&ER`&QS965K-C0`7U]E<G)N;U]L;V-A=&EO;@!E>&ET`')E
M861L:6YK`%]?<W1A8VM?8VAK7V9A:6P`86-C97-S`&UK9&ER`%]?96YV:7)O
M;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L
M+G-O+C4N,S0`;&EB8RYS;RXV`&QD+6QI;G5X+6%R;6AF+G-O+C,`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`7U]B<W-?<W1A
M<G1?7P!S:&%?=7!D871E`'AS7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?
M7V)S<U]S=&%R=`!S:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?
M:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P``````
M`````@`!``(``@`!``$``0`!``$``@`!``$``@`!``(``0`!``(``@`"``(`
M`0`#``$``0`!``$``0`"``(``@`"``$``@`"``0``@`"``$``@`!``(``0`"
M``(``@`"``(``@`#``4``@`"``(``0`"``$``@`"``(``0`"``(``@`!``(`
M`0`%``(``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`-0,``!`````@````
M%&EI#0``!`"3!`````````$``P`K`P``$`````````"TD98&```%`)T$```0
M````LY&6!@```P"H!```$````!1I:0T```(`DP0```````"\_0$`%P```,#]
M`0`7````_/\!`!<````$``(`%P````P``@`7````$``"`!<````8``(`%P``
M`!P``@`7````(``"`!<````D``(`%P```"@``@`7````,``"`!<````T``(`
M%P```#P``@`7````S/\!`!4(``#0_P$`%0H``-3_`0`5"P``V/\!`!42``#<
M_P$`%1@``.#_`0`5&P``Y/\!`!4<``#H_P$`%20``.S_`0`5)@``\/\!`!4^
M``#T_P$`%3\``/C_`0`52P``V/X!`!8#``#<_@$`%@0``.#^`0`6!0``Y/X!
M`!8&``#H_@$`%@<``.S^`0`6"0``\/X!`!8+``#T_@$`%@P``/C^`0`6#0``
M_/X!`!8.````_P$`%@\```3_`0`6$```"/\!`!81```,_P$`%A,``!#_`0`6
M%```%/\!`!85```8_P$`%A8``!S_`0`6%P``(/\!`!89```D_P$`%AH``"C_
M`0`6'0``+/\!`!8>```P_P$`%A\``#3_`0`6(```./\!`!8A```\_P$`%B(`
M`$#_`0`6(P``1/\!`!8E``!(_P$`%B<``$S_`0`6*```4/\!`!8I``!4_P$`
M%BH``%C_`0`6*P``7/\!`!8L``!@_P$`%BT``&3_`0`6+@``:/\!`!8O``!L
M_P$`%C```'#_`0`6,0``=/\!`!8R``!X_P$`%C,``'S_`0`6-```@/\!`!8U
M``"$_P$`%C8``(C_`0`6-P``C/\!`!8Y``"0_P$`%CH``)3_`0`6.P``F/\!
M`!8\``"<_P$`%D```*#_`0`600``I/\!`!9"``"H_P$`%D,``*S_`0`61```
ML/\!`!9%``"T_P$`%D8``+C_`0`61P``O/\!`!9(``#`_P$`%DD``,3_`0`6
M2@``R/\!`!9+```(0"WI/`$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EY.P!``#&
MC^(>RHSBY/R\Y0#&C^(>RHSBW/R\Y0#&C^(>RHSBU/R\Y0#&C^(>RHSBS/R\
MY0#&C^(>RHSBQ/R\Y0#&C^(>RHSBO/R\Y0#&C^(>RHSBM/R\Y0#&C^(>RHSB
MK/R\Y0#&C^(>RHSBI/R\Y0#&C^(>RHSBG/R\Y0#&C^(>RHSBE/R\Y0#&C^(>
MRHSBC/R\Y0#&C^(>RHSBA/R\Y0#&C^(>RHSB?/R\Y0#&C^(>RHSB=/R\Y7A'
M_><`QH_B'LJ,XFC\O.4`QH_B'LJ,XF#\O.4`QH_B'LJ,XEC\O.4`QH_B'LJ,
MXE#\O.4`QH_B'LJ,XDC\O.4`QH_B'LJ,XD#\O.4`QH_B'LJ,XCC\O.4`QH_B
M'LJ,XC#\O.4`QH_B'LJ,XBC\O.4`QH_B'LJ,XB#\O.4`QH_B'LJ,XAC\O.4`
MQH_B'LJ,XA#\O.4`QH_B'LJ,X@C\O.4`QH_B'LJ,X@#\O.4`QH_B'LJ,XOC[
MO.4`QH_B'LJ,XO#[O.4`QH_B'LJ,XNC[O.4`QH_B'LJ,XN#[O.5X1_WG`,:/
MXA[*C.+4^[SE`,:/XA[*C.+,^[SE`,:/XA[*C.+$^[SE`,:/XA[*C.*\^[SE
M`,:/XA[*C.*T^[SE`,:/XA[*C.*L^[SE`,:/XA[*C.*D^[SE`,:/XA[*C.*<
M^[SE`,:/XA[*C.*4^[SE`,:/XA[*C.*,^[SE`,:/XA[*C.*$^[SE>$?]YP#&
MC^(>RHSB>/N\Y0#&C^(>RHSB</N\Y0#&C^(>RHSB:/N\Y0#&C^(>RHSB8/N\
MY0#&C^(>RHSB6/N\Y0#&C^(>RHSB4/N\Y0#&C^(>RHSB2/N\Y0#&C^(>RHSB
M0/N\Y7A'_><`QH_B'LJ,XC3[O.4`QH_B'LJ,XBS[O.4`QH_B'LJ,XB3[O.4`
MQH_B'LJ,XAS[O.4`QH_B'LJ,XA3[O.4`QH_B'LJ,X@S[O.4`QH_B'LJ,X@3[
MO.4`QH_B'LJ,XOSZO.4`QH_B'LJ,XO3ZO.5PM5M-B+!;2WU$6TS-Z000!:@#
MD@2I`ZI\1.M8&V@'DT_P``/_]\+O5$I52Z)8X%@11@+PO?I32^-8'7@`+6O0
M44OD6"!H__=F[P-&(&B3^,8C0O`"`H/XQB/_]USO!9V0^,8S*AT#-4/P`0.R
M\8!/@/C&,W/2D`#_]VSO0TH$G`-&>D1"27E$4&`B:!I@04H%F'I$VF!`2@$H
M"6AZ1)E@6F!>W2$=!.N`#@/Q#`Q1^`1+3/@$3W%%^=$#,#=.`"$`D2I&?D1#
M^"`0-4GP:'E$__<^[@1&>+,R30:N?43H:/_WSNXP2#%&>$0`\.7X0+,N2WM$
MV&C_]Q3N__>`[BQ*'$MZ1--8&F@'FUI`3_```RG1($8(L'"]__=*[B5*>D30
M8!"S__=V[A=+Y%@@:/_W\NZ`^'M7A>?P:/_W'.X$1LKGJ&@0L0'P_?K1YQI(
M,49X1`#PL?BH8``HR=#SY__WG.X$(*KG__>X[@$@__<V[^CI`0`@`0``V.D!
M``0!```8`0``*`$````!``#FZ@$`VNH!`,(H``"T*```I.H!`!\&``",Z@$`
M-"8``';J`0#NZ`$`2NH!`&@E``!/\``+3_``#@*\:D8$M`&TW_@8H`6CFD1/
M\``#"+0$2%KX``#_]^KN__>B[0SH`0`P`0``%#"?Y10@G^4#,(_@`B"3YP``
M4N,>_R\!T_[_ZO3G`0`(`0``!D@'2P=*>$1[1'I$@T(#T`5+TU@#L1A'<$<`
MOTKI`0!(Z0$`TN<!``P!```(2`E+>$0)2GM$&QIZ1-D/`>NC`4D0`]`%2]-8
M`[$81W!'`+\@Z0$`'.D!`*3G`0`0`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(
M2WM$&&C_][+N__>__P9+`2)[1!IP"+WJZ`$`=.<!`"P!``">Z`$`RN@!`,3G
M`+\MZ?A#@48?2WM$`"@VT!Y*FUC3^`"`N/$`#S'0!7@/1@`M&+\]+12_`24`
M)1/1V/@`0&RQ1D8@1BI&24;_]T;N$+EC73TK$-!6^`1/`"SRT2!&O>CX@P5&
M%?@!/P`K&+\]*_G1I>L)!>'GINL(!@$U+$2V$#Y@($:]Z/B#!$;GYT1&Y><P
MYP$`'`$``#A*.4MZ1"WI\$&>L--8&V@=DT_P``,0L0-X!$9CN3-*,4MZ1--8
M&F@=FUI`3_```U71'K"]Z/"!__?<[`5&`"CMT"M/?T0H1O_W[NT`*#70PWP`
M\1,&+BL"T7-X`"ORT,-\+BLQT"!&__<X[8!&,$;_]S3M0$0",/_WANT[1D_P
M_S(!(0&6!D8`E/_WU.T"J3!&__<,[0$P,$8%T`:;`_1P0[/U@$\7T/_W'NTP
M1O_W[.PH1O_WN.T`*,G1*$;_]T3M($;_]WCMJ>=S>"XKRM&S>``KM]#&Y__W
MDO_FY__W6NT`OZCF`0`@`0``BN8!`-`B```72AA+>D00M01&G+#36&E&&V@;
MDT_P``/_]UKMH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P
M``,+T1RP$+T`(/'G`B$@1O_WK.RP^H#P0`GIY__W(.VTY0$`(`$``(3E`0`M
MZ?!##D8L22Q+K?6`77E$@[`$1@WU@%`$,-_XI(#+6`&O0/;_<CE&&V@#8$_P
M``,D2/A$>$3_]T+ML/$`#!O=`JT,\?\Y3405^`0\@[NY\0`/$=!*1B\A.$;_
M]V+M6+$92UCX`S`8:/_W`NU+1CI&(4;_]YSL">`32UCX`S`8:/_W]NPR1B%&
M__<T[`]*#?6`40I+!#%Z1--8&F@+:%I`3_```P;1#?6`70.PO>CP@^%&S^?_
M][[L/N4!`"`!```:Y0$`B"$````!``"VY`$`6$I92WI$+>GP1PQ&@K`%1M-8
MW_A8@1MH`9-/\``#"WCX1#TK"+\!-"!&__=`[&E&!D8H1O_WAOZ!1@`H5-#_
M]S;LAD)'V4I+`)]8^`.`OP`K>``K&+\]*Q2_`2,`(P?0*T83^`$O`"H8OSTJ
M^=%;&[`<V/@`8!A$__=N[/!1Z+'8^``P*$;961#X`3L+<``K&+\]*PG02AP0
M^`$[$48"^`$[/2L8OP`K]M$*1CTC"W`4^`$[`O@!/P`K^=$M2BI+>D336!IH
M`9M:0$_P``-&T0*PO>CPAPGQ_SD4^`$["?@!/P`K^='IYR%+6/@#@-CX`'`[
M:(.S.T93^`0O248)\0$)`"KXT0,QB0`;2GI$$VB[N0A&`2,38/_W'NR"1@`H
MS-`Y1D_JB0<Z1O_W0.S(^`"@S?@`D`GQ`0D`(TKX*3"&YSA&__=R[()&R/@`
M```HM-!/ZHD'[.>91@@AU>?_]P+L`+]XY`$`(`$``%SD`0`<`0``O.,!`.CD
M`0`PM1%,$4N#L'Q$Y5@H:/_W"NPH:/_W!NP-2@Y+#DE[1*)8>43_]S[L*&C_
M]_SK"TL+2@`D"TE[1'I$S>D`-'E$__=JZP.P,+WXX@$```$``!0!```B7P``
M7A\``"8B``!1#@``7A\``!"U"$P(2WQ$XU@8:/_WUNL&2@=+!TE[1*)8>42]
MZ!!`__<*O)+B`0```0``%`$``,)>``#^'@``)$HPM21+>D2M]0!=B;`-]0!1
M!:S36!PQ&V@+8$_P``/_]\KK'4E!\@$"'4MY1,WI``%[1`$A($;_]];K#?6`
M41@Q($9/](!2`Y'_]\+K!!ZXOP`E"MM@'/_W<.L%1BBQ`YDB1O_W(.L`(RM5
M#4H-]0!1"4L<,7I$TU@::`MH6D!/\``#!-$H1@WU`%T)L#"]__=:ZUKB`0`@
M`0``]!X``.(>``#JX0$`__>JOUM*+>GP3P9&6DMZ1*WUA%V#L%E(#?6$5`WQ
M&`C36`U&>$1!1@0T&V@C8$_P``/_]R7]+R$$1C!&__=XZL"Q3T@Q1GA$__=X
M_C!&34H-]8112$L$,7I$TU@::`MH6D!/\``#0/"#@`WUA%T#L+WH\(\P1O_W
MN.J!1BA&__?XZD%)>43_]QCK`"C9T#]+!T;?^/R@>T0%DSY+^D1[1`23.W@`
M*S[0++$Y1B!&__=TZP`H0=`X1O_WENI"'KL8NEPO*@;1`"4=<`$X$_@!+2\J
M^=`)\0$#`T2S]8!?L-HM2B&M`2%31GI$*$;-Z0$F3_2`4@"7__<DZT%&*$;_
M]USJ*+D*FP/T<$.S]0!/'=`B20`@>43_]]#J!T8`+Y#0.W@`*\#1!+,C>"XK
M`M`%GP$@S^=C>``K^=$920`@>43_][KJ!T8`+^K1>N<!(2A&__<LZ@`HV]$2
M2"E&>$3_]^W]*$;_]X3J<><$GP$@L>?_]Y;JJN$!`"`!``!<'@``1AX``&#A
M`0`8'@``YAT```0>``#>'0``P!T``(@=``!>'0``,!T```-X.[%"'"\K"+\0
M1A+X`3L`*_C1<$<`OQ"UJ+,#>`1&D[/_]P[J0QXC1)Q",M(:1@+@$T:B0BW0
M$T82^`$9+RGWT)Q")M(!.YQ")=`:>"\J^=$!.P/@$7@!.R\I`M$:1IQ"^-,2
M&Y,<L_6`7XB_`"`)V!%((49/](!3`3)X1`1&__>@Z2!&$+T,2+WH$$!X1/_W
M&+J<0MS1(W@O*P70"$B]Z!!`>$3_]PVZ!DB]Z!!`>$3_]P>Z`+\<X0$`1AP`
M`%P<```D'```S$K-2WI$<+7,3H*PS$W36'Y$;$9]1!MH`9-/\``#(48P1O_W
M]?NPL<9+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__??
M^P`HZ-&\3GY$(48P1O_WU_NPL;=+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__?!^P`HZ-&N3GY$(48P1O_WN?NPL:A+`)CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>C^P`HZ-&@3GY$(48P1O_W
MF_NPL9E+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__>%
M^P`HZ-&23GY$(48P1O_W??NPL8I+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__=G^P`HZ-&$3GY$(48P1O_W7_NPL7M+`)CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__=)^P`HZ-%V3GY$(48P1O_W
M0?NPL6Q+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__<K
M^P`HZ-%H3GY$(48P1O_W(_NPL5U+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__<-^P`HZ-%:3GY$(48P1O_W!?NPL4Y+`)CK6!EH`>N`
M`UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?O^@`HZ-%,3GY$(48P1O_W
MY_JPL3]+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH0_@$*P`J^M$A1C!&__?1
M^@`HZ-$^3GY$(48P1O_WR?JPL3!+`)CK6!EH`>N``UIH0?@@(``J[]`$,UIH
M0_@$*P`J^M$A1C!&__>S^@`HZ-$P2"%&>$3_]ZSZ`488L2U(>$3_]P3\+$@A
M1GA$__>A^@%&&+$J2'A$__?Y^RE((49X1/_WEOH!1K"Q)DAX1/_W[OLE2A%+
M>D336!IH`9M:0$_P``,5T2%)(DAY1'A$`K"]Z'!`__?;NQ]((49X1/_W>/H!
M1@`HY-`<2'A$__?/^]_G__=^Z$3?`0`@`0``+!P``#3?`0`<`0``\!L``+P;
M``",&P``6!L``"P;``",&@``P!H``)`:``!@&@``J!D``/(9``#.&0``\!D`
M`/@9``#Z&0``)AD``%3<`0#T&0``6AD``,X9``!8&0``%TL821A*>T1Y1`"U
M&&B#L(I80QP2:`&23_```@S0$TH12WI$TU@::`&;6D!/\``#$]$#L%WX!/L-
M2&E&>$3_]QGZ,+$`>#`H&+\`*!2_`2``(`A+>T088.'G__<<Z`"_XMP!`*3;
M`0`@`0``BML!`*@8``"4W`$`"+7^]W[O_O?`[P"Q`&@(O2Y*+TMZ1/"U+DZ'
ML`5&TUA^1`2I,$8;:`633_```__WY?D0L0-X!$:+N2=*)$MZ1--8&F@%FUI`
M3_```SS1(T@I1GA$!["]Z/!`__<MNRE&_O>D[UBQ'DH92WI$TU@::`6;6D!/
M\``#)M$'L/"]*$;^]W#O!T8@1O[W;.\X1`(P_O>^[Q-+%$H!(7M$`I1Z1`"5
M`9)/\/\R!$;_]PCH#TH'2WI$TU@::`6;6D!/\``#!+\A1C!&Q=#^]ZCO(-L!
M`"`!``#,&```]MH!`)H8``#*V@$`@A<``'H7``""V@$`+>GP3]_X-!6M]0%-
MW_@P18&PW_@PI7Q$0*\B':?Q=`,'D`WU`$7?^"`%!/$0#/PU*#1X1*?Q:`ZG
M\>`&^D1!6`EH*6!/\``!I_%<!0?*@^@'`+SH#P`/Q9SH`P"%Z`,`E.@'`([H
M!P#?^.`$,49X1/_W3/D@L0-X!$8`*T#P6('^]\;N_O<([P`H`/!I@05H`"T`
M\(N!*$;^]^SN0``!,/[W/N\J>(!&@K'?^*2T1$;[1"!&`));1D_P_S(!(0(T
M_O>$[Q7X`2\`*O+1W_B$!*?Q7`5X1`+@5?@$#XBQ,4;_]Q3Y!$8`*/;0`W@`
M*_/0__?,^0`H[]`@1O[W`.\$1L"Y3_``":?Q=`L'ZXD"4OAT3'2Q"^N)!2)X
M4K$@1@GQ`0G_][/Y`"A9T57X!$\`+/+1`"0@1O[WGNZ#1D!&_O>:[H-$"_($
M2UA&_O?J[M_X"#1/\/\R`2%[1`*3_TO-^`R`@$9[1`&3_4L`E'M$_O<N[T_T
MX'%`1O[W]NT!,`71_O=<[P%H$2E`\,*`,49`1O[WY.X%1DBS\DD'F_)*6O@!
M`$_P``H;:'I$S?@`@`$A`&C^]\+N[4H-]0!!WTO\,7I$TU@::`MH6D!/\``#
M0/"S@5!&#?4!30&PO>CPCR!&_O>,[@1&`"B/T*/G5_C0/`/T<$.S]8!/SM%7
M^,A,_O<([H1"R-%7^-`\P_,(`[/UX'_!T5A&_O>$[H)&U$@Q1GA$__=S^`%&
M`"@`\,&`!YL8:/_W+?N#1@`H`/"Y@%A&_O<8[@1&`R@/V<I)!#A81'E$_O?H
M[D"Y!"P`\"J!7$04^`4\+RL`\"2!PTQ\1"-H6AP`\*&``"L`\+.`OTG`2'E$
MW_@`DWA$OT__]YWYOT[^]X3NODM/\/\R`2%[1`.3O$OY1,WX`(!_1'M$S>D!
M,+E+4$9^1'M$_O>([A3@_O>^[@-H$2L7T?[W:.X!-81&2T8B1@$A4$;-Z0-7
MS>D!;,WX`(#^]W+N3_3@<5!&_O<\[01&0QSBT$!&_O>2[:=(449X1/_W8/E0
M1O_W"?Y2YY1*!YM:^`(`3_``"AMHH$K-Z0"!`2%Z1`!H_O<&[D+G__?V_9M*
M@4L-]0!!>D3\,=-8&F@+:%I`3_```T#P](`@1@WU`4T!L+WH\$_^]\R]!$:G
M\6@(!^N$`U/X:`RHL0CKA`4"X%7X!`]XL3%&`33^]\3_`"CVT`-X`"OST/[W
MMNT%1@`H?_1^KN3G@DT-(/[WONU3(H!&?41^YBQ&V.<'F]/X`+!"YWQ(,49X
M1/[WI?\`*`#PBH`#>``K&+\P*Q6_`2,`(P$C(V`8OR-@?_1-KUA&`"'^]V3M
M!$8`*#_T1:]/\/\S;_`1`@(F/1\`EO[WB.T&(BE&($;^]Q#M%_@$/!NY%_@#
M/$,K8=``(P`B`),@1@`C_O=V[0#PY_\&1@/@*48P1@'P'?A/]`!"*48@1O[W
M].P"'O/<W_ADL2!&I_$P"?[W..VG\44%,4;[1$Q&I_$Q!J?Q1``!\&WX%?@!
M+R!&`));1D_P_S(!(?[WINT"-*Y"\M%*2@$AS?@(D%!&>D1(2\WI`((`(@?X
M""Q[1$9*>D0#DD_P_S+^]X[M(N<'FUQH`"P_]->N($;^]]KL`RA_]M&N/4D$
M."!$>43^]ZCM`"@(OZ-&QN8@8(#G%_@"/$$KF=$7^`$\0RN5T3MX2"N2T7MX
M12N/T4_P_S-O\#D"($8`EO[W!.TI1BDB($;^]XSL*TLK24_P_S)[1,WI`E,I
M2WE$4$;-Z0"!>T0!(?[W3.W?YO[W^.P@`0``:ML!``C:`0`2V@$`GA8``&07
M``#T%@``T!8``-`5``"P%@``)`$``,06``"$V`$`H!8``'@6```4V0$`>!4`
M`/84``!6%@``^!8``(`4```$%P``BA0``#(6```*%```"A4```C7`0!D%```
MP!,``+83``"B$@``.!0``/P4```"%```@A0```X2``"J$P``7TA@27A$\+5?
M2X.P7TI!6'M$;D8):`&13_```9Q8(&C^][KL!48@:/[WMNPQ1I7X:#"`^&DP
M5DAX1/[W?_X0L0-X,2MZT/_W<?H@:/[WI.Q020,C`2)Y1/[WU.L%1FBQ(&C^
M]YKL*VE+2AEH>D3^]];K*VD;:)MH6P)NU"!H_O>,[$9)`R,!(GE$_O>\ZP5&
M>+%#2#%&>$3^]U#^!T8@:``O3]#^]WCL*VDZ1AEH_O>VZR!H_O=P[`5&(&C^
M]VSL.$D!(GE$_O>`ZS=*`48H1GI$-DW^]Z+K(&C^]U[L`T9]1#-(`"(Q1GA$
M@_AI(/[W)?X$1JA@L+%/].!Q($;^]TSK0AP#1A$H&+\!*B_8*4H<2WI$TU@:
M:`&;6D!/\``#(]$#L/"]:&C_]X+\!$:H8``HX=$@2'A$_O="[$-X`"N#T(#G
M_O<H[!Q+*FE[1!!H6V@9:/[WZ/ZKYR!H_O<<["MI&6C^]^CKB.?^]_CK%$DB
M1A1(>41X1$EH"6C^]R#L<-0!`"`!``!DU`$```$``%@1``#F$@``U!(``,`2
M``"R$```B!(``)02```,U0$`5!```&+3`0`V$@``H-0!`'C4`0`:$@``,DHS
M2WI$\+4'1H.PTU@;:`&33_```__W3?D#>`1&.[%"'"\K"+\41A+X`3L`*_C1
M*$X]'AB_`25^1#-H6APLT``K#+\`)07P`05=N2)*($MZ1--8&F@!FUI`3_``
M`S+1`[#PO3MX`"OPT!Q)!"(@1GE$_O?FZP`HZ-$92A1+>D336!IH`9M:0$_P
M``,;T3A&`["]Z/!`_O>SO1)(:49X1/[W:/UHL0-X`"L8OS`K"K\`(P$C,V#)
MT`$C,V``+<70T.<P8,+G_O=FZP"_J-(!`"`!``"PTP$`7-(!`"`0```NT@$`
M1@\````````MZ?!/`/%``=_X8$O?^&`[K?4C?7Q$[D9R1@#Q@`P`)^-8&VBA
MDT_P``-1Z0)D5V#78!`R-KI"^!!L(PHE`@/T?T,(,4/J%&,%]'\%0^H$8V%%
M0^H%`T+X"#SFT:WQ"`8.]?QW`".$1C1&5O@(#]3I!H4B;]3X2*!A;]3X3)""
MZ@H"=&B"Z@@"@>H)`4)`:4#&^(0P84"4&-(/OD)"ZD$"0NH$`L;X@"#>T6!&
MWO@`4-SI`R:$:-SI`'E/ZI0(`IE(ZH)X1_:9$L7V@B)(ZH1X!&JM&$_JUVS=
M^!#@3.I)'"T9A&E,ZD<<'.L%!=WX<*"&Z@0,A&@,Z@0,A&F,Z@0,%>L,!8;J
M"`R)&`SJ!PP)&8SJ!@P1ZPP,'NL"`4_JEPZ)&4[JB7[=^!B03NJ'=`SK]6R(
MZ@0.#NH%#D_JM06.Z@@.$>L.#AGK`@$1ZP@!A.H%"-WX()`(Z@P(B.H$"`[K
M_&X1ZP@(3^J\#!GK`@'=^"B0"1F%Z@P$!.H.!`CK_FAL0$_JO@X,&1GK`@%)
M&8SJ#@7=^#"0!>H(!87J#`4$Z_AD31E/ZK@(&>L"`=WX.)`1ZPP!CNH(#`SJ
M!`P%Z_1EC.H.#$_JM`01ZPP,&>L"`1'K#@&(Z@0.W?A`D`[J!0Z.Z@@.#.OU
M;!'K#@Y/ZK4%&>L"`=WX2)`1ZP@!A.H%"`CJ#`@.Z_QNB.H$"$_JO`P1ZP@(
M&>L"`0D9A>H,!-WX4)`$Z@X$;$`(Z_YH#!E/ZKX.&>L"`=WX6)!)&8SJ#@4%
MZ@@%!.OX9(7J#`5/ZK@(31D9ZP(!$>L,`8[J"`S=^&"0#.H$#(SJ#@P%Z_1E
M$>L,#$_JM`09ZP(!W?AHD!'K#@&(Z@0.#NH%#@SK]6R.Z@@.3^JU!1'K#@X9
MZP(!$>L(`83J!0@(Z@P(#NO\;HCJ!`A/ZKP,$>L("!KK`@$)&87J#`0(Z_YI
M!.H.!-WX>(!L0$_JO@X)&1CK`@3=^("`9!F,Z@X%!>H)!0'K^6&%Z@P%3^JY
M"609&.L"!17K#`6.Z@D,W?B(@`SJ`0R,Z@X,!.OQ9!7K#`Q/ZK$!&.L"!=WX
MD*`5ZPX%B>H!#@[J!`X,Z_1LCNH)#D_JM`05ZPX%&NL"#A[K"0Z!Z@0)!>O\
M:`GJ#`DFG8GJ`0E/ZKP,'NL)#JH8W?B@H%(8A.H,`0'J"`$.Z_AN84!/ZK@%
M41A.]J$RQO;98MWXJ(`:ZP(*`>O^81KK!`2,Z@4*BNH."D_JO@X4ZPH$W?BP
MD!CK`@B%Z@X*!.OQ9(KJ`0H8ZPP,3^JQ`=WXN(`<ZPH,&>L""8[J`0H,Z_1L
MBNH$"AGK!05/ZK0$%>L*!=WXP)`8ZP((@>H$"@7K_&6*Z@P*&.L.#D_JO`P>
MZPH.W?C(@(3J#`H9ZP()BNH%"AGK`0D.Z_5A&>L*"4_JM048ZP(*W?C0X!KK
M!`H)Z_%DC.H%"8GJ`0E/ZK$!&NL)"A[K`@G=^-B`&>L,"0KK]&R%Z@$*BNH$
M"D_JM`09ZPH)&.L""MWXX.`:ZP4*">O\98'J!`F)Z@P)3^J\#!KK"0H>ZP()
MW?CH@!GK`0D*Z_5AA.H,"HKJ!0I/ZK4%&>L*"1CK`@C=^/#@&.L$"`GK\62,
MZ@4)B>H!"4_JL0$8ZPD('NL"#MWX^*`>ZPP.A>H!#`CK]&B,Z@0,3^JT!-WX
M`)$>ZPP.&NL"#('J!`H.Z_ANBNH("ASK!0Q/ZK@('.L*#$*=A.H("AGK`@D,
MZ_YLBNH."AGK`0E/ZKX.&>L*"429K1B(Z@X*BNH,"BP9">O\94_JO`P4ZPH$
MW?@8D8[J#`J)&`3K]62*Z@4*$>L(`4_JM041ZPH!C.H%"AGK`@D!Z_1ABNH$
M"MWX(($9ZPX)3^JT"QGK"@G=^"CA">OQ9!CK`@B%Z@L)&.L,"(GJ`0E/ZK$!
M&.L)"=WX,,$>ZP(*B^H!#H[J!`X:ZP4*">OT94_JM`0:ZPX*@>H$"-WX..$<
MZP(,B.H%"!SK"PP*Z_5J'.L(#$_JM04>ZP("4AB$Z@4!W?A`X8'J"@%/ZKH(
M41A+]MQ"R/8;<@SK^FP>ZP(.1>H("MWX2)$>ZP0$"NH,"@7J"`X!Z_QA2NH.
M"D_JO`P4ZPH.&>L"!&092.H,!0CJ#`K=^%"1#4`.Z_%N1>H*!4_JL0$M&1GK
M`@E,Z@$$&>L("@SJ`0O=^%B1!.H.!`7K_F5$Z@L$3^J^#A3K"@09ZP()&>L,
M"4'J#@P!Z@X*W?A@@0SJ!0P$Z_5D3.H*#$_JM04<ZPD,&.L""!CK`0$,Z_1H
M3NH%#`[J!0K=^&B1#.H$#$SJ"@Q/ZK0$'.L!#!GK`@E%Z@0!&>L."@7J!`O=
M^'"1`>H(`0SK^&Q!Z@L!3^JX#A'K"@$9ZP()&>L%"@'K_&5$Z@X!3^J\"=WX
M>($!Z@P!!.H.#$'J#`$1ZPH,&.L"`0D93NH)!`[J"0K=^("!+$`,Z_5L1.H*
M!$_JM05D&$GJ!0H8ZP((!.O\9!CK#@ABF4_JO`X*Z@P*">H%#$KJ#`H:ZP@,
MB1@1ZPD(1>H."07J#@IDF0GJ!`D,Z_1L2>H*"4_JM`09ZP@(B1A)&4[J!`4.
MZ@0)!>H,!47J"04(Z_QH;1AFF4_JO`P%Z_AEB1A$Z@P)!.H,"A'K#@X)Z@@)
M:)E)Z@H)3^JX"!GK#@F)&!'K!`X)Z_5D3.H("0SJ"`IJF0GJ!0E)Z@H)3^JU
M!1GK#@Z)&!'K#`%(Z@4,".H%"0SJ!`Q,Z@D,#NOT;ASK`0QLF4_JM`0,Z_YL
MB1A%Z@0)!>H$"A'K"`@)Z@X);IE)Z@H)3^J^#AGK"`F)&!'K!0@)Z_QE1.H.
M"03J#@IPF0GJ#`E)Z@H)3^J\#!GK"`E.Z@P(B1@(Z@4("1D)Z_5D#NH,"4_J
MM05(Z@D(3.H%"1CK`0ARF0SJ!0H)Z@0)B1@(Z_1H$>L.#G293^JT!$GJ"@D9
MZPX)B1A%Z@0.">OX:1'K#`H.Z@@.3^JX#':9!>H$"$-@3NH(#@3J#`@>ZPH.
MBAA2&43J#`4%Z@D%>)E%Z@@%#NOY;JT83/+6$LSV8B)/ZKD)$>L""'J9&.L$
M"(SJ"02$Z@X$!>O^91CK!`A/ZKX.B1B)Z@X$$>L,#'R9;$`(Z_5H'.L$#$_J
MM06)&([J!001ZPD)?ID,Z_ALA.H(!!GK!`E/ZK@(C!B`F13K#@0)Z_QNA>H(
M"<-@B>H,"4_JO`P4ZPD$$>L""1GK!0F"F8CJ#`4$Z_YDA>H.!4_JO@X9ZP4)
MC1@5ZP@%A)D)Z_1HC.H."8GJ!`E/ZK0$%>L)!1'K`@D9ZPP)AIF.Z@0,!>OX
M98SJ"`Q#81GK#`E/ZK@,$>L""(B9&.L."`GK]6Z$Z@P)PV&)Z@4)3^JU!1CK
M"0@1ZP()&>L$"8J9".O^9(SJ!0B(Z@X(3^J^#AGK"`D1ZP((&.L,"(R9">OT
M;(7J#@F)Z@0)3^JT!!CK"0@1ZP()&>L%"8Z9".O\98[J!`B(Z@P(3^J\#!GK
M"`D1ZP((&.L.")"9">OU;H3J#`F)Z@4)3^JU!1CK"0@1ZP()&>L$"9*9".O^
M9(SJ!0B(Z@X(3^J^#AGK"`D1ZP((&.L,")29">OT;(7J#@F)Z@0)3^JT!!CK
M"0@1ZP()&>L%"9:9".O\98[J!`B(Z@P(3^J\#!GK"`D1ZP((&.L.")B9">OU
M;H3J#`F)Z@4)3^JU!1CK"0B)&!'K!`D(Z_YDFIF,Z@4(B.H."$_JO@X9ZP@)
MB1@1ZPP(">OT;(7J#@F<F8GJ!`E/ZK0$&.L)"8D8">O\:4T9GID&Z[D&!F&.
MZ@0&ANH,!D_JO`RM&8H8TAF$Z@P!@>H)`1+K#@(%Z_EE4AB!:`+K]6)I&(5I
M`F`":ASK!06!8*08"TK`Z0A#"4MZ1(5ATU@::*&;6D!/\``#`]$-]2-]O>CP
MC_WWH.T`OZS1`0`@`0``=,8!``BU@"#]]X[MG^T/>P`B@F>`[0![G^T.>X#M
M`GN?[0Y[@.T$>Y_M#GN`[09[G^T.>X#M"'N?[0Y[@.T*>X#M#'L(O0"_K_,`
M@`$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````````
M`````"WI^$,%1A9&@&H`(PQ&]Q?5Z0PA`.O&#(1%Z&ISZP```M(!,D'Q``&H
M;P7Q.`C%Z0K#<P]#ZL<#FQ@K8T'K5W%I8X"[/RY#W:;Q0`E/ZID6=QP$ZX<7
M(49#1@3Q0`[1^`#`$#%1^`Q,$#-1^`@,4?@$+'%%0_@0S$/X#$Q#^`@,0_@$
M+.O1#$8H1O_WP?F\0N'1J>N&%C)&.49`1OWWO.RN9[WH^(/`\4`'(4:W0D!$
MJ+\W1CI&_?>P[*MO.T2K9T`K[M$H1O8;/$3_]Z'YN><G1N#G+>GP00'Q.`<,
M1HMJ!48.:X`AD_J#^,/SQ0,VNEH<N!@X*OE41-W"\4`"`"']]S3L($;_]X/Y
M.$8X(@`A_?<L["!&Q.D<:/_W>?GC>"MP($9CB&MP(V@;"JMP(VCK<.-Z*W%C
MB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR(VGK<N-^*W-CBVMSHVD;"JMS
MHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP0?WW$KS"\3@"`"']]_#KP><"
M2WM$&VC]][F\`+]VQ0$`"$`MZ0B`O>@!``(`.P```#X````+````/@```!``
M```^````)0```#X````S````/@````,````^````!@```#X````4````/@``
M``X````^````#0```#X````D````/@```!(````^````)P```#X````"````
M/@```!@````^````"0```#X````*````/@``````````````)7,O)7,````O
M<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%2
M7U1%35``````4$%27U!23T=.04U%`````#H````E<R5S)7,``"\```!015),
M-4Q)0@````!015),3$E"`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!
M4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$
M25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@`````Q````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E
M<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N
M<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E
M;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%
M4E-)3TX`````,2XP-34```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C
M=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@``
M``!54T523D%-10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X96,@
M+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R
M=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@
M*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@
M)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@
M)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN
M(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE
M)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D
M8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["B10
M05)?34%'24,@/2`B7&Y005(N<&U<;B(["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H
M<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N
M)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-
M04=)0SL*?0IM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R!?1D@["FUY("1M86=I8U]P;W,@/2`D<VEZ92`M("1S
M:7IE("4@)&-H=6YK7W-I>F4[(",@3D]413H@)&UA9VEC7W!O<R!I<R!A(&UU
M;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I
M('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D
M8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`]
M(')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S
M("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*
M:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I
M8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I
M;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`[
M"G)E860@7T9(+"`D8G5F+"`T.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@
M)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O
M9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@)&]F9G-E="P@
M,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E
M860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@
M<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C
M:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S
M879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA
M;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F
M(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L
M(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@
M)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@
M)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M
M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!
M4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T
M92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H
M)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]
M"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M
M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M
M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE
M;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA
M;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E
M('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA
M;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<,#`S7#`P-"(I('L*;W5T<RAQ
M<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0II9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@
M)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D
M97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1T:"P@(CPZ<F%W(BP@)&]U=#L*
M)&-T>"T^861D9FEL92@D=&@I.PIC;&]S92`D=&@["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#`@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B7#!#04-(
M12(["FUY("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE7VYA
M;64I("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M+`IP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^8VQO
M<V4*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z
M("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*")2
M96%D:6YG($U%5$$N>6UL+BXN(BD["FEF("AM>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.EQS*B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*:68@*&UY("@D8VQE86XI(#T@
M)&UE=&$@/7X@+UY<<RMC;&5A;CH@*"XJ*20O;2D@>PHD8VQE86X@/7X@+UY<
M<RI\7',J)"]G.PHD14Y6>U!!4E]#3$5!3GT@/2`Q(&EF("1C;&5A;CL*?0I]
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M
M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I
M<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*
M;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A
M8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L
M;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0
M?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD
M<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?
M5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@
M)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?
M=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP
M;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@
M*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M
M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA
M;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER
M("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P
M=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!
M4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@
M97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M<&5R;'AS:2YC````.P```#X````+````/@```!`````^````)0```#X````S
M````/@````,````^````!@```#X````4````/@````X````^````#0```#X`
M```D````/@```!(````^````)P```#X````"````/@```!@````^````"0``
M`#X````*````/@``````````````[)K_?P$`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````C1<``$T7```!````&P,```$````K`P``
M`0```#4#```,````S!$```T```"8.@``&0```+S]`0`;````!````!H```#`
M_0$`'`````0```#U_O]OM`$```4````L"0``!@```)P"```*````LP0```L`
M```0````%0`````````#````S/X!``(```#H`0``%````!$````7````Y`\`
M`!$````4#P``$@```-`````3````"````!X````(````^___;P$```C^__]O
MM`X``/___V\"````\/__;^`-``#Z__]O#@``````````````````````````
M``````````````````````````````#$_0$```````````#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$`
M`-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``
MV!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8
M$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$`
M`-@1``#8$0``````````````````````````````````````````````````
M````````````````V10````````$``(`_____U0^``"0.P```````%`\``!4
M/```2#X``)@[``!0/@```````#0^```\/@```````%P^``!'0T,Z("A58G5N
M='4@,3$N,RXP+31U8G5N='4Q*2`Q,2XS+C``03(```!A96%B:0`!*`````4W
M+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A
M=&$`+D%232YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R
M87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M````````"P````$````"````5`$``%0!```9```````````````!````````
M`!,````'`````@```'`!``!P`0``)```````````````!``````````F````
M!P````(```"4`0``E`$``"````````````````0`````````-````/;__V\"
M````M`$``+0!``#H````!0`````````$````!````#X````+`````@```)P"
M``"<`@``D`8```8````#````!````!````!&`````P````(````L"0``+`D`
M`+,$``````````````$`````````3@```/___V\"````X`T``.`-``#2````
M!0`````````"`````@```%L```#^__]O`@```+0.``"T#@``8`````8````"
M````!`````````!J````"0````(````4#P``%`\``-`````%``````````0`
M```(````<P````D```!"````Y`\``.0/``#H`0``!0```!4````$````"```
M`'P````!````!@```,P1``#,$0``#```````````````!`````````!W````
M`0````8```#8$0``V!$````#``````````````0````$````@@````$````&
M````V!0``-@4``#`)0`````````````(`````````(@````!````!@```)@Z
M``"8.@``"```````````````!`````````".`````0````(```"@.@``H#H`
M``A!``````````````0`````````E@````$``'""````J'L``*A[```(````
M#0`````````$`````````*$````!`````@```+![``"P>P``!```````````
M````!`````````"K````#@````,```"\_0$`O/T```0```````````````0`
M```$````MP````\````#````P/T!`,#]```$```````````````$````!```
M`,,````&`````P```,3]`0#$_0``"`$```8`````````!`````@```#,````
M`0````,```#,_@$`S/X``#0!``````````````0````$````T0````$````#
M```````"`````0!````````````````$`````````-<````(`````P```$``
M`@!```$`%!``````````````!`````````#<`````0```#``````````0``!
M`"4```````````````$````!````Y0````,``'```````````&4``0`S````
M```````````!``````````$````#``````````````"8``$`]0``````````
+`````0``````````
